pub enum TokenType {
Show 54 variants
LeftParen,
RightParen,
LeftBracket,
RightBracket,
LeftBrace,
RightBrace,
Dot,
Comma,
Plus,
Percent,
Minus,
Semicolon,
Not,
NotEqual,
Equal,
EqualEqual,
Greater,
GreaterEqual,
Less,
QuestionMark,
LessEqual,
Slash,
Colon,
RawString,
Star,
String,
Bytes,
RawBytes,
Ident,
Int(i64),
Uint(u64),
Double(f64),
And,
As,
Break,
Const,
Else,
False,
For,
Function,
If,
Import,
Let,
Loop,
Null,
In,
Or,
True,
Var,
Package,
Namespace,
Void,
While,
Dyn,
}Expand description
TokenType represents the type of the token. It is used by the parser to build the AST. The parser is responsible for deciding how to interpret the token.
Variants
LeftParen
RightParen
LeftBracket
RightBracket
LeftBrace
RightBrace
Dot
Comma
Plus
Percent
Minus
Semicolon
Not
NotEqual
Equal
EqualEqual
Greater
GreaterEqual
Less
QuestionMark
LessEqual
Slash
Colon
RawString
Star
String
Bytes
RawBytes
Ident
Int(i64)
Uint(u64)
Double(f64)
And
As
Break
Const
Else
False
For
Function
If
Import
Let
Loop
Null
In
Or
True
Var
Package
Namespace
Void
While
Dyn